from typing import Union

import numpy as np
import pyvista as pv
from MeshAnim.time_series import TimeSeries
from pyvistaqt import QtInteractor

from MeshObject import Mesh, TMeshLoadable


class PvInter(QtInteractor):
    def __init__(self, **kwargs):
        super().__init__(**kwargs)
    def set_key_events(self): ...
    @QtInteractor.theme.setter
    def theme(self, theme): ...
    def add_points(
        self,
        coords: Union[np.ndarray, TMeshLoadable]=None,
        labels=None,
        point_size=20,
        render_points_as_spheres=True,
        always_visible=True,
        italic=False,
        bold=True,
        font_size=None,
        text_color=None,
        font_family=None,
        shadow=False,
        show_points=True,
        point_color=None,
        name=None,
        shape_color="grey",
        shape="rounded_rect",
        fill_shape=True,
        margin=3,
        shape_opacity=1.0,
        pickable=False,
        tolerance=0.001,
        reset_camera=None,
        render=True,
    ): ...
    def add_point(
        self,
        coord=None,
        label=None,
        point_size=20,
        render_points_as_spheres=True,
        always_visible=True,
        italic=False,
        bold=True,
        font_size=None,
        text_color=None,
        font_family=None,
        shadow=False,
        show_points=True,
        point_color=None,
        name=None,
        shape_color="grey",
        shape="rounded_rect",
        fill_shape=True,
        margin=3,
        shape_opacity=1.0,
        pickable=False,
        tolerance=0.001,
        reset_camera=None,
        render=True,
    ): ...
    def add_mesh(
        self,
        obj: Union[Mesh, pv.DataSet],
        color=None,
        style=None,
        scalars=None,
        clim=None,
        show_edges=None,
        edge_color=None,
        point_size=5.0,
        line_width=None,
        opacity=1.0,
        flip_scalars=False,
        lighting=None,
        n_colors=256,
        interpolate_before_map=True,
        cmap=None,
        label=None,
        reset_camera=None,
        scalar_bar_args=None,
        show_scalar_bar=None,
        multi_colors=False,
        name=None,
        texture=None,
        render_points_as_spheres=None,
        render_lines_as_tubes=False,
        smooth_shading=None,
        split_sharp_edges=False,
        ambient=0.0,
        diffuse=1.0,
        specular=0.0,
        specular_power=100.0,
        nan_color=None,
        nan_opacity=1.0,
        culling=None,
        rgb=None,
        categories=False,
        silhouette=False,
        use_transparency=False,
        below_color=None,
        above_color=None,
        annotations=None,
        pickable=True,
        preference="point",
        log_scale=False,
        pbr=False,
        metallic=0.0,
        roughness=0.5,
        render=True,
        component=None,
        radius=None,
        **kwargs
    ):
        pass
    def add_line(
        self,
        p1,
        p2,
        color=None,
        style=None,
        scalars=None,
        clim=None,
        show_edges=None,
        edge_color=None,
        point_size=5.0,
        line_width=None,
        opacity=1.0,
        flip_scalars=False,
        lighting=None,
        n_colors=256,
        interpolate_before_map=True,
        cmap=None,
        label=None,
        reset_camera=None,
        scalar_bar_args=None,
        show_scalar_bar=None,
        multi_colors=False,
        name=None,
        texture=None,
        render_points_as_spheres=None,
        render_lines_as_tubes=False,
        smooth_shading=None,
        split_sharp_edges=False,
        ambient=0.0,
        diffuse=1.0,
        specular=0.0,
        specular_power=100.0,
        nan_color=None,
        nan_opacity=1.0,
        culling=None,
        rgb=None,
        categories=False,
        silhouette=False,
        use_transparency=False,
        below_color=None,
        above_color=None,
        annotations=None,
        pickable=True,
        preference="point",
        log_scale=False,
        pbr=False,
        metallic=0.0,
        roughness=0.5,
        render=True,
        component=None,
        radius=None,
        **kwargs
    ):
        pass
    def add_vector(
        self,
        p1,
        *,
        p2=None,
        direction=None,
        scale=None,
        color=None,
        style=None,
        scalars=None,
        clim=None,
        show_edges=None,
        edge_color=None,
        point_size=5.0,
        line_width=None,
        opacity=1.0,
        flip_scalars=False,
        lighting=None,
        n_colors=256,
        interpolate_before_map=True,
        cmap=None,
        label=None,
        reset_camera=None,
        scalar_bar_args=None,
        show_scalar_bar=None,
        multi_colors=False,
        name=None,
        texture=None,
        render_points_as_spheres=None,
        render_lines_as_tubes=False,
        smooth_shading=None,
        split_sharp_edges=False,
        ambient=0.0,
        diffuse=1.0,
        specular=0.0,
        specular_power=100.0,
        nan_color=None,
        nan_opacity=1.0,
        culling=None,
        rgb=None,
        categories=False,
        silhouette=False,
        use_transparency=False,
        below_color=None,
        above_color=None,
        annotations=None,
        pickable=True,
        preference="point",
        log_scale=False,
        pbr=False,
        metallic=0.0,
        roughness=0.5,
        render=True,
        component=None,
        **kwargs
    ): ...
    def add_vectors(
        self,
        obj: Union[Mesh, pv.DataSet, np.array],
        array_name: str = None,
        scale=None,
        color=None,
        style=None,
        scalars=None,
        clim=None,
        show_edges=None,
        edge_color=None,
        point_size=5.0,
        line_width=None,
        opacity=1.0,
        flip_scalars=False,
        lighting=None,
        n_colors=256,
        interpolate_before_map=True,
        cmap=None,
        label=None,
        reset_camera=None,
        scalar_bar_args=None,
        show_scalar_bar=None,
        multi_colors=False,
        name=None,
        texture=None,
        render_points_as_spheres=None,
        render_lines_as_tubes=False,
        smooth_shading=None,
        split_sharp_edges=False,
        ambient=0.0,
        diffuse=1.0,
        specular=0.0,
        specular_power=100.0,
        nan_color=None,
        nan_opacity=1.0,
        culling=None,
        rgb=None,
        categories=False,
        silhouette=False,
        use_transparency=False,
        below_color=None,
        above_color=None,
        annotations=None,
        pickable=True,
        preference="point",
        log_scale=False,
        pbr=False,
        metallic=0.0,
        roughness=0.5,
        render=True,
        component=None,
        **kwargs
    ): ...
    def add_mesh_threshold(
        self,
        obj,
        scalars=None,
        invert=False,
        widget_color=None,
        preference="cell",
        title=None,
        pointa=(0.4, 0.9),
        pointb=(0.9, 0.9),
        continuous=False,
        **kwargs
    ): ...
    def add_ts(
        self,
        ts: TimeSeries,
        color=None,
        style=None,
        scalars=None,
        clim=None,
        show_edges=None,
        edge_color=None,
        point_size=5.0,
        line_width=None,
        opacity=1.0,
        flip_scalars=False,
        lighting=None,
        n_colors=256,
        interpolate_before_map=True,
        cmap=None,
        label=None,
        reset_camera=None,
        scalar_bar_args=None,
        show_scalar_bar=None,
        multi_colors=False,
        name=None,
        texture=None,
        render_points_as_spheres=None,
        render_lines_as_tubes=False,
        smooth_shading=None,
        split_sharp_edges=False,
        ambient=0.0,
        diffuse=1.0,
        specular=0.0,
        specular_power=100.0,
        nan_color=None,
        nan_opacity=1.0,
        culling=None,
        rgb=None,
        categories=False,
        silhouette=False,
        use_transparency=False,
        below_color=None,
        above_color=None,
        annotations=None,
        pickable=True,
        preference="point",
        log_scale=False,
        pbr=False,
        metallic=0.0,
        roughness=0.5,
        render=True,
        component=None,
        **kwargs
    ): ...
    def add_orientation_widget(
        self, obj, position=(0, 0.9, 0.15, 1), interactive=None, color=None, opacity=1.0
    ): ...
