import logging
import sys
import traceback
from dataclasses import dataclass
from typing import TypeVar, Union

import pyvista as pv
from PyQt5 import QtWidgets
from pyvista import themes

from MeshObject.bindvista.window import BaseWindow
from MeshObject.bindvista.interactor import PvInter

# T = TypeVar("T", bound="PvInter")


class Plotter:
    def __init__(self, size=(1200, 912), title="Title", no_orientation=False, **cfg):
        self.cfg = {**cfg, "title": title, "size": size, "border": False}
        self.no_ori = no_orientation

    def __enter__(self) -> Union[PvInter, pv.Plotter]:
        self.app = QtWidgets.QApplication(sys.argv)
        self.window = BaseWindow(**self.cfg)
        if not self.no_ori:
            self.window.plotter.add_camera_orientation_widget()
        return self.window.plotter

    def __exit__(self, exc_type, exc_val, exc_tb):
        if exc_type is not None:
            log.error(f"{exc_type.__name__}: {exc_val}")
            traceback.print_tb(exc_tb)
        if not self.cfg.get("off_screen", False):
            self.app.exec_()


@dataclass
class Themes:
    PV = themes.ParaViewTheme()
    PV.show_edges = True

    DOC = themes.DocumentTheme()
    DOC.show_edges = True
    # DOC.slider_styles.modern.selected_color = "k"

    NUM = pv.themes.DefaultTheme()
    NUM.color = "#ffab6d"
    NUM.show_edges = True
    NUM.edge_color = "k"
    NUM.background = "#ffd36d"
    NUM.nan_color = None
    try:
        NUM.enable_camera_orientation_widget = True
    except:
        pass


log = logging.getLogger(__name__)
